@@ -21,7 +21,11 @@ if lua_version < "5.3" then
          debug, io, math, package, string, table
    local io_lines = io.lines
    local io_read = io.read
+   local io_open = io.open
+   local io_popen = io.popen
+   local io_tmpfile = io.tmpfile
    local unpack = lua_version == "5.1" and unpack or table.unpack
+   local debug_setmetatable = type(debug) == "table" and debug.setmetatable
 
    -- create module table
    M = {}
@@ -75,6 +79,15 @@ if lua_version < "5.3" then
    end
 
 
+   -- load io functions
+   local io_ok, iolib = pcall(require, "compat53.io")
+   if io_ok then
+      for k,v in pairs(iolib) do
+         M.io[k] = v
+      end
+   end
+
+
    -- load string packing functions
    local str_ok, strlib = pcall(require, "compat53.string")
    if str_ok then
@@ -491,7 +504,6 @@ if lua_version < "5.3" then
       if type(debug) == "table" then
          local debug_setfenv = debug.setfenv
          local debug_getfenv = debug.getfenv
-         local debug_setmetatable = debug.setmetatable
 
          M.debug = setmetatable({}, { __index = debug })
 
@@ -865,6 +877,63 @@ if lua_version < "5.3" then
          end
       end -- not luajit
 
+      -- NOTICE:
+      -- Disable this compatibility override because it overwrites the file
+      -- meta type from FILE* to userdata, and does not seems to be needed.
+      if false and is_luajit then
+         local compat_file_meta = {}
+         local compat_file_meta_loaded = 0
+
+         local function load_compat_file_meta(file_meta)
+            -- fill compat_file_meta with original entries
+            for k, v in pairs(file_meta) do
+               compat_file_meta[k] = v
+            end
+            compat_file_meta.__index = {}
+            for k, v in pairs(file_meta.__index) do
+               compat_file_meta.__index[k] = v
+            end
+
+            compat_file_meta_loaded = 1
+
+            -- update it with compatibility functions
+            local file_mt_ok, file_mt = pcall(require, "compat.file_mt")
+            if file_mt_ok then
+               file_mt.update_file_meta(compat_file_meta, is_luajit52)
+
+               compat_file_meta_loaded = 2
+            end
+         end
+
+         local function return_fd(fd, err, code)
+            if not fd then
+               return fd, err, code
+            end
+            if fd and debug_setmetatable then
+               if compat_file_meta_loaded == 0 then
+                  local file_meta = gmt(fd)
+                  load_compat_file_meta(file_meta)
+               end
+               if compat_file_meta_loaded == 2 then
+                  debug_setmetatable(fd, compat_file_meta)
+               end
+            end
+            return fd
+         end
+
+         function M.io.open(...)
+            return return_fd(io_open(...))
+         end
+
+         function M.io.popen(...)
+            return return_fd(io_popen(...))
+         end
+
+         function M.io.tmpfile(...)
+            return return_fd(io_tmpfile(...))
+         end
+      end
+
    end -- lua 5.1
 
    -- further write should be forwarded to _G
