@@ -5,10 +5,11 @@
 #include <lauxlib.h>
 #include <lualib.h>
 
-/* compatibility layer: https://github.com/keplerproject/lua-compat-5.3 */
+/* compatibility layer: https://github.com/lunarmodules/lua-compat-5.3 */
 #include "compat/compat-5.3.h"
 
 #define API_TYPE_FONT "Font"
+#define API_TYPE_REGEX "Regex"
 #define API_TYPE_THREAD "Thread"
 #define API_TYPE_CHANNEL "Channel"
 #define API_TYPE_PROCESS "Process"
