@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <stdbool.h>
 #include <stdint.h>
+#include <stdlib.h>
 #include <assert.h>
 #include <math.h>
 #include <ft2build.h>
@@ -18,6 +19,7 @@
 // #define RENDERER_DEBUG
 
 static RenWindow **window_list = NULL;
+static RenWindow *target_window = NULL;
 static size_t window_count = 0;
 
 // draw_rect_surface is used as a 1x1 surface to simplify ren_draw_rect with blending
@@ -395,17 +397,18 @@ static void font_file_close(FT_Stream stream) {
 
 static int font_set_face_metrics(RenFont *font, FT_Face face) {
   FT_Error err;
-  int font_size = font->size * font->scale;
-  if ((err = FT_Set_Pixel_Sizes(face, 0, font_size)) != 0)
+  float pixel_size = font->size;
+  #ifdef PRAGTICAL_USE_SDL_RENDERER
+  pixel_size *= font->scale;
+  #endif
+  if ((err = FT_Set_Pixel_Sizes(face, 0, (int) pixel_size)) != 0)
     return err;
 
   font->face = face;
   if(FT_IS_SCALABLE(face)) {
-  font->height = (short)((face->height / (float)face->units_per_EM) * font_size);
-  font->baseline = (short)((face->ascender / (float)face->units_per_EM) * font_size);
-
-  if(FT_IS_SCALABLE(face))
-    font->underline_thickness = (unsigned short)((face->underline_thickness / (float)face->units_per_EM) * font_size);
+    font->height = (short)((face->height / (float)face->units_per_EM) * font->size);
+    font->baseline = (short)((face->ascender / (float)face->units_per_EM) * font->size);
+    font->underline_thickness = (unsigned short)((face->underline_thickness / (float)face->units_per_EM) * font->size);
   } else {
     font->height = (short) font->face->size->metrics.height / 64.0f;
     font->baseline = (short) font->face->size->metrics.ascender / 64.0f;
@@ -716,11 +719,27 @@ int ren_font_group_get_height(RenFont **fonts) {
 }
 
 // some fonts provide xadvance for whitespaces (e.g. Unifont), which we need to ignore
-#define FONT_GET_XADVANCE(F, C, M) (is_whitespace((C)) || !(M) || !(M)->xadvance \
-  ? (F)->space_advance * (float) ((C) == '\t' ? (F)->tab_size : 1) \
-  : (M)->xadvance)
+float font_get_xadvance(RenFont *font, unsigned int codepoint, GlyphMetric *metric, double curr_x, RenTab tab) {
+  if (!is_whitespace(codepoint) && metric && metric->xadvance) {
+    return metric->xadvance;
+  }
+  if (codepoint != '\t') {
+    return font->space_advance;
+  }
+  float tab_size = font->space_advance * font->tab_size;
+  if (isnan(tab.offset)) {
+    return tab_size;
+  }
+  double offset = fmodl(curr_x + tab.offset, tab_size);
+  float adv = tab_size - offset;
+  // If there is not enough space until the next stop, skip it
+  if (adv < font->space_advance) {
+    adv += tab_size;
+  }
+  return adv;
+}
 
-double ren_font_group_get_width(RenFont **fonts, const char *text, size_t len, int *x_offset) {
+double ren_font_group_get_width(RenFont **fonts, const char *text, size_t len, RenTab tab, int *x_offset) {
   double width = 0;
   const char* end = text + len;
 
@@ -730,7 +749,7 @@ double ren_font_group_get_width(RenFont **fonts, const char *text, size_t len, i
     text = utf8_to_codepoint(text, end, &codepoint);
     GlyphMetric *metric = NULL;
     font_group_get_glyph(fonts, codepoint, 0, NULL, &metric);
-    width += FONT_GET_XADVANCE(fonts[0], codepoint, metric);
+    width += font_get_xadvance(fonts[0], codepoint, metric, width, tab);
     if (!set_x_offset && metric) {
       set_x_offset = true;
       *x_offset = metric->bitmap_left; // TODO: should this be scaled by the surface scale?
@@ -763,13 +782,14 @@ void ren_font_dump(RenFont *font) {
 }
 #endif
 
-double ren_draw_text(RenSurface *rs, RenFont **fonts, const char *text, size_t len, float x, float y, RenColor color) {
+double ren_draw_text(RenSurface *rs, RenFont **fonts, const char *text, size_t len, float x, float y, RenColor color, RenTab tab) {
   SDL_Surface *surface = rs->surface;
   SDL_Rect clip;
   SDL_GetClipRect(surface, &clip);
 
   const double surface_scale_x = rs->scale_x, surface_scale_y = rs->scale_y;
   double pen_x = x * surface_scale_x;
+  double original_pen_x = pen_x;
   y *= surface_scale_y;
   const char* end = text + len;
   uint8_t* destination_pixels = surface->pixels;
@@ -836,7 +856,7 @@ double ren_draw_text(RenSurface *rs, RenFont **fonts, const char *text, size_t l
       }
     }
 
-    float adv = FONT_GET_XADVANCE(fonts[0], codepoint, metric);
+    float adv = font_get_xadvance(fonts[0], codepoint, metric, pen_x - original_pen_x, tab);
 
     if(!last) last = font;
     else if(font != last || text == end) {
@@ -1009,3 +1029,13 @@ RenWindow* ren_find_window_from_id(uint32_t id) {
   SDL_Window *window = SDL_GetWindowFromID(id);
   return ren_find_window(window);
 }
+
+RenWindow* ren_get_target_window(void)
+{
+  return target_window;
+}
+
+void ren_set_target_window(RenWindow *window)
+{
+  target_window = window;
+}
